/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/
#include <SDL/SDL.h>
#include <SDL/SDL_image.h>
#include "button.h"
#include "../lunaticinterface.h"

LunaticButton::LunaticButton(const std::string& basefn, const std::string& extfn, const std::string& rsrcpath, int x, int y)
    : mX(x), mY(y)
{

    mNormal = IMG_Load((rsrcpath + basefn + "." + extfn).c_str());
    if(!mNormal)
    {
        // not having even a normal image is a critical problem
        throw std::string("Button ") + rsrcpath + basefn + "." + extfn + " not found";
    }

    // others are not critical; they can be null if not loaded
    mHover = IMG_Load((rsrcpath + basefn + "_hover." + extfn).c_str());
    mDown = IMG_Load((rsrcpath + basefn + "_down." + extfn).c_str());


    mFileName=rsrcpath + basefn + "." + extfn;

}


const LunaticButton& LunaticButton::operator=(const LunaticButton& old)
{
    mNormal=old.mNormal;
    mHover=old.mHover;
    mDown=old.mDown;
    mX=old.mX;
    mY=old.mY;
    mFileName=old.mFileName;


    if(mNormal) mNormal->refcount++;
    if(mHover) mHover->refcount++;
    if(mDown) mDown->refcount++;
    return *this;
}


LunaticButton::LunaticButton()
    : mNormal(NULL),
      mHover(NULL),
      mDown(NULL),
      mX(0),
      mY(0),
      mFileName("")
{
    // dummy constructor
    // just initializes to faulty, but constant and recognizable values
}


LunaticButton::~LunaticButton()
{
    SDL_FreeSurface(mNormal);
    SDL_FreeSurface(mHover);
    SDL_FreeSurface(mDown);
}

void LunaticButton::paintSelf(LunaticInterface* parent, btnstate_t state)
{
    if(!mNormal)
        throw std::string("NULL mNormal in ") + __PRETTY_FUNCTION__;

    switch(state)
    {
        default:
        case NORMAL:
        parent->blitSurface(mNormal, mX, mY);
        break;

        case HOVER:
        parent->blitSurface(mHover ? mHover : mNormal, mX, mY);
        break;

        case DOWN:
        parent->blitSurface(mDown ? mDown : mNormal, mX, mY);
        break;
    }
}


bool LunaticButton::pointInside(int x, int y)
{
    return (x > mX && x <= mX + mNormal->w &&
            y > mY && y <= mY + mNormal->h);
}
