/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef LUNATIC_BUTTON_H_INCLUDED
#define LUNATIC_BUTTON_H_INCLUDED

#include <string>
struct SDL_Surface;
class LunaticInterface;

/** \brief GUI button for lunatic interface.
  * This class implements a button for use in the lunatic interface.
  * It incorporates handling whether we're pressing inside a button,
  * depending on parent's choice displaying normal, hover and down image,
  * etc.
  */

class LunaticButton
{
    public:

    enum btnstate_t
    {
        NORMAL, HOVER, DOWN
    };

    /** \brief Dummy. Do not use
      * This is a dummy constructor so that STL and C++ don't go haywire when
      * we declare a non-pointer LunaticButton in a container or a class.
      * Do not use! A button thus constructed is invalid.
      */
    LunaticButton();

    /** \brief Initializes the button.
      * \param basefn A string specifying base of filenames, e.g. for "mybtn*.png" it's "mybtn"
      * \param extfn A string specifying extension of filenames, e.g. for "mybtn*.png" it's "png"
      * \param rsrcpath Resource path; where can we find the actual button files
      * \param x Target where to render; X coordinate
      * \param y Target where to render; Y coordinate
      */
    LunaticButton(const std::string& basefn, const std::string& extfn, const std::string& rsrcpath, int x, int y);

    ~LunaticButton();

    const LunaticButton& operator=(const LunaticButton& old);

    /** \brief Paints the button
      * \param parent LunaticInterface which contains this button and provides blitting functionality
      * \param state State which needs to be painted: NORMAL, HOVER or DOWN
      */
    void paintSelf(LunaticInterface *parent, btnstate_t state=NORMAL);

    /** \brief Returns if point is inside
      * \param x X coordinate of point
      * \param y Y coordinate of point
      * \return bool whether or not point is inside
      * This function is used for checking if mouse event is inside button.
      * Decides solely based on mNormal.
      */
    bool pointInside(int x, int y);

    private:
    SDL_Surface *mNormal, *mHover, *mDown;
    int mX, mY;
    std::string mFileName; // debug only
};


#endif
