/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include <SDL/SDL_image.h>
#include <SDL/SDL_rotozoom.h>
#include "userbox.h"
#include "defines.h"
#include "../../authprovider.h"
#include "../lunaticinterface.h"
#include "../../utils.h"

LunaticUserbox::LunaticUserbox(std::string username, std::string displayname, std::string rsrcpath, int x, int y)
    : mDisplayName(displayname), mX(x), mY(y)
{

    mCurrentDim = 1;

    {

        // There are some places where we can find an icon for the user.
        //
        // = Home folder, file called .face; this is used at least by gnome.
        // = Default fallback image specified by theme.

        std::string homedir;
        SDL_Surface* s=NULL;
        homedir=AuthProvider::getHomeDir(username);
        if(homedir!="")
        {
            s = IMG_Load((homedir + "/.face").c_str());
        }

        if(!s)
        {
            s = IMG_Load((rsrcpath + "rootuser.png").c_str());
        }

        if (!s)
        {
            throw std::string("Could not load resource");
        }

        // We need to resize the icon to fit 48 x 48 space allocated for
        // it.
        if(s->w > s->h)
            mImgUser = zoomSurface(s, 48./s->w, 48./s->w, 0);
        else
            mImgUser = zoomSurface(s, 48./s->h, 48./s->h, 0);

        SDL_FreeSurface(s);
    }

}

void LunaticUserbox::paintSelf(LunaticInterface* parent, SDL_Surface *bg, float dimmed, std::string instruction, std::string asterisks)
{

    int x = mX; // REMOVEME
    int y = mY;

    parent->blitSurface(bg, x,y);

    // draw user image
    parent->blitSurface(mImgUser, x+12 + (48-mImgUser->w)/2, y+11  + (48-mImgUser->h)/2);

    // draw username
    parent->mActiveFont=parent->mInstructionFont;
    parent->mFontForeCol.r = parent->mFontForeCol.g = parent->mFontForeCol.b = 255;
    parent->mFontBackCol.r = 0x5a; parent->mFontBackCol.g = 0x7e; parent->mFontBackCol.b = 0xdb;
    parent->mFontShaded=LunaticInterface::BLENDED;
    parent->fontDrawText(mDisplayName.c_str(), x + parent->mImgLoginBox1->w + 3, y + INSTRUCTION_SIZE/2);

    // draw instruction such as "type password"
    parent->mActiveFont=parent->mFont;
    parent->mFontForeCol.r = parent->mFontForeCol.g = parent->mFontForeCol.b = 255;
    parent->mFontShaded=LunaticInterface::BLENDED;
    parent->fontDrawText(instruction.c_str(), x + parent->mImgLoginBox1->w, y + INSTRUCTION_SIZE/2 + 24);

    // draw asterisks
    parent->mActiveFont=parent->mFont;
    parent->mFontForeCol.r = parent->mFontForeCol.g = parent->mFontForeCol.b = 0;
    parent->mFontShaded=LunaticInterface::BLENDED;
    parent->fontDrawText(asterisks.c_str(), x + parent->mImgLoginBox1->w, y + INSTRUCTION_SIZE/2 + 24 + 24);

    mWantDim=dimmed;
    if (mCurrentDim!=1)
    {
        SDL_SetAlpha(parent->mImgBG, SDL_SRCALPHA, Min(256*mCurrentDim, 255.));
        parent->blitSurface(parent->mImgBG, x, y, 0,0, parent->mImgLoginBox2->w, parent->mImgLoginBox2->h);
    }
    SDL_SetAlpha(parent->mImgBG, 0, 255);

}

void LunaticUserbox::updateSelf(float k)
{
    if(mCurrentDim!=mWantDim)
    {
        float sgn = Signum(mWantDim-mCurrentDim);
        if(sgn < 0) sgn *=2;

        if(mCurrentDim*sgn<mWantDim*sgn)
        {
            mCurrentDim+=k * 2 *  sgn;
        }

        if(mCurrentDim*sgn>=mWantDim*sgn){
            mCurrentDim = mWantDim;
        }
    }
}

bool LunaticUserbox::pointInside(LunaticInterface *parent, int x, int y)
{
    return (x > mX && x <= mX + parent->mImgLoginBox2->w &&
            y > mY && y <= mY + parent->mImgLoginBox2->h);
}
