/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef LUNATICINTERFACE_H_INCLUDED
#define LUNATICINTERFACE_H_INCLUDED

#include <SDL/SDL_ttf.h>
#include <vector>
#include <map>
#include <string>
#include "../sdlinterface.h"
#include "lunatic/userbox.h"
#include "lunatic/button.h"


/** This class tries to implement a XP-like SDL-based login interface.
  *
  * \todo Document member functions properly
  */

struct SDL_Surface;
class LunaticInterface : public SDLInterface
{
    friend class LunaticUserbox;
    enum lunaticfontshade_t { SOLID, SHADED, BLENDED };

    public:
    LunaticInterface();
    ~LunaticInterface();

    void paintSelf();
    void updateSelf(double k);
    bool isFinished();
    bool isCanceled();

    const std::string& getInterfaceName() const { static const std::string name = "LunaticInterface"; return name; }

    const std::string& getLogin() const;
    const std::string& getPassword() const;


    void showSelf();

    AuthProvider* getSucceedingAuthProvider() const { return mSucceedingProvider; }

    private:

    bool loadResources(const std::string&path);
    void unloadResources();

    SDL_Surface *mImgBG, *mImgGlow, *mImgTop, *mImgBottom, *mImgSeparator, *mImgDistLogo, *mImgLoginBox1, *mImgLoginBox1a, *mImgLoginBox2;
    SDL_Surface *mImgQuitBtnNormal;

    LunaticButton mBtnTurnOff; LunaticButton::btnstate_t mTurnOffBtnState;

    int fontDrawChar(char t, int x1, int y1);
    void fontDrawText(std::string txt_s, float x, float y);
    float fontSize(std::string txt);

    TTF_Font *mFont;
    TTF_Font *mWelcomeFont, *mInstructionFont, *mMOTDFont;
    TTF_Font *mActiveFont;
    SDL_Color mFontForeCol, mFontBackCol;

    std::map<std::string, LunaticUserbox> mUserList;
    std::string mHoveredUser;


    std::string mRsrcPath;

    std::string mMOTD; // after you log on ...

    bool mEnteringLogin, mEnteringPassword;
    std::string mLogin, mPassword;
    AuthProvider *mSucceedingProvider;

    lunaticfontshade_t mFontShaded;

};

#endif
