/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#ifndef SIMPLESDLINTERFACE_H_INCLUDED
#define SIMPLESDLINTERFACE_H_INCLUDED

#include <SDL/SDL_ttf.h>
#include "../sdlinterface.h"


/** This class provides a simple SDL-based login interface.
  *
  * It's ugly and poor, but its simplicity allows rapid testing of
  * authorization features.
  *
  * \todo Document member functions properly
  */

class SimpleSDLInterface : public SDLInterface
{
    public:
    SimpleSDLInterface();
    ~SimpleSDLInterface();

    void paintSelf();
    void updateSelf(double k);
    bool isFinished();
    bool isCanceled();

    const std::string& getInterfaceName() const { static const std::string name = "SimpleSDLInterface"; return name; }

    const std::string& getLogin() const;
    const std::string& getPassword() const;


    void showSelf();

    AuthProvider* getSucceedingAuthProvider() const { return mSucceedingProvider; }

    private:
    int fontDrawChar(char t, int x1, int y1);
    void fontDrawText(std::string txt_s, float x, float y);
    float fontSize(std::string txt);

    TTF_Font* mFont;

    bool mEnteringLogin, mEnteringPassword;
    std::string mLogin, mPassword;
    AuthProvider *mSucceedingProvider;
};

#endif
