/*
GLDM - Graphical Liberty Display Manager

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include <sstream>

#include <signal.h>
#include <sys/ioctl.h>
#include <stdio.h>
#include <unistd.h>

#include "terminalinterface.h"
TerminalInterface::TerminalInterface()
{
    mForkedPid=0;
    mEnteringLogin = mEnteringPassword = 0;
}

TerminalInterface::~TerminalInterface()
{
}

void TerminalInterface::showSelf()
{
    if(mForkedPid!=0)
        return;

    pipe(mIODescriptors);

    if(!(mForkedPid=fork()))
    {
        std::stringstream arg;
        arg << "-Sgldm/" << mIODescriptors[0];
        execlp("xterm", "xterm",  arg.str().c_str(), (char*)NULL);
    }

    mEnteringLogin = true;
    mEnteringPassword = false;

    // wait for xterm's readiness
    //usleep(500000); // let's presume it won't take more than 0.5 sec for xterm to start...

    dprintf(mIODescriptors[1], "login: \n");

}

void TerminalInterface::hideSelf()
{
    if(mForkedPid==0)
        return;
    kill(mForkedPid, SIGTERM);
    mForkedPid=0;
}

void TerminalInterface::paintSelf()
{
}
void TerminalInterface::updateSelf(double k)
{
    fd_set fds;
    FD_ZERO(&fds);
    FD_SET(mIODescriptors[1], &fds);

    printf("Selecting...\n");
    int affected = select(mIODescriptors[1]+1, &fds, NULL, NULL, NULL);
    if(!affected) // nothing was sent to our pipe (user didn't enter anything) -- skip
    {
        return;
    }

    int size=0;
    if(ioctl(mIODescriptors[1], FIONREAD, &size) == -1)
    {
        return; // on error, just return...
    }

    char* buf = new char[size+1];
    read(mIODescriptors[1], buf, size);
    buf[size+1]=0;
    printf(buf);
    dprintf(mIODescriptors[1], buf);

    delete[] buf;
}
bool TerminalInterface::isFinished()
{
    return false;
}
bool TerminalInterface::isCanceled()
{
    return false;
}

const std::string& TerminalInterface::getLogin() const
{
    static const std::string r = "";
    return r;
}
const std::string& TerminalInterface::getPassword() const
{
    static const std::string r = "";
    return r;
}
